@@ -9,7 +9,7 @@
 //
 /**@name game.cpp - The game set-up and creation. */
 //
-//      (c) Copyright 1998-2007 by Lutz Sammer, Andreas Arens, and
+//      (c) Copyright 1998-2008 by Lutz Sammer, Andreas Arens, and
 //                                 Jimmy Salmon
 //
 //      This program is free software; you can redistribute it and/or modify
@@ -39,7 +39,6 @@
 
 #include "stratagus.h"
 #include "map.h"
-#include "tileset.h"
 #include "minimap.h"
 #include "player.h"
 #include "unit.h"
@@ -79,6 +78,9 @@ GameResults GameResult;                      /// Outcome of the game
 --  Functions
 ----------------------------------------------------------------------------*/
 
+static void WriteCreateUnits(FileWriter *f);
+static void WriteCreateUnit(FileWriter *f, const CUnit *unit);
+
 /*----------------------------------------------------------------------------
 --  Map loading/saving
 ----------------------------------------------------------------------------*/
@@ -110,7 +112,7 @@ static void LoadStratagusMap(const std::string &smpname, const std::string &mapn
 		strcpy_s(mapfull, sizeof(mapfull), StratagusLibPath.c_str());
 		strcat_s(mapfull, sizeof(mapfull), "/");
 		strcat_s(mapfull, sizeof(mapfull), smpname.c_str());
-		char *p = strrchr(mapfull, '/');
+		p = strrchr(mapfull, '/');
 		if (!p) {
 			p = mapfull;
 		} else {
@@ -178,9 +180,9 @@ static int WriteMapPresentation(const std::string &mapname, CMap *map)
 	try {
 		f = CreateFileWriter(mapname);
 		f->printf("-- Stratagus Map Presentation\n");
-		f->printf("-- File generated by the stratagus builtin editor.\n");
+		f->printf("-- File generated by the Bos Wars builtin editor.\n");
 		// MAPTODO Copyright notice in generated file
-		f->printf("-- File licensed under the GNU GPL version 2.\n\n");
+		f->printf("-- File licensed under the GNU GPL version 2 or later.\n\n");
 
 		f->printf("DefinePlayerTypes(");
 		while (topplayer > 0 && map->Info.PlayerType[topplayer] == PlayerNobody) {
@@ -213,22 +215,21 @@ static int WriteMapPresentation(const std::string &mapname, CMap *map)
 /**
 **  Write the map setup file.
 **
-**  @param mapsetup      map filename
-**  @param map           map to save
-**  @param writeTerrain  write the tiles map in the .sms
+**  @param mapSetup  map filename
+**  @param map       map to save
 */
-int WriteMapSetup(const char *mapsetup, CMap *map, int writeTerrain)
+int WriteMapSetup(const char *mapSetup, CMap *map)
 {
 	FileWriter *f = NULL;
-	int i, j;
+	int i;
 
 	try {
-		f = CreateFileWriter(mapsetup);
+		f = CreateFileWriter(mapSetup);
 	
 		f->printf("-- Stratagus Map Setup\n");
-		f->printf("-- File generated by the stratagus builtin editor.\n");
+		f->printf("-- File generated by the Bos Wars builtin editor.\n");
 		// MAPTODO Copyright notice in generated file
-		f->printf("-- File licensed under the GNU GPL version 2.\n\n");
+		f->printf("-- File licensed under the GNU GPL version 2 or later.\n\n");
 	
 		f->printf("-- player configuration\n");
 		for (i = 0; i < PlayerMax - 1; ++i) {
@@ -239,37 +240,15 @@ int WriteMapSetup(const char *mapsetup, CMap *map, int writeTerrain)
 		}
 		f->printf("\n");
 
-		f->printf("-- load tilesets\n");
-		f->printf("LoadTileModels(\"%s\")\n\n", map->TileModelsFileName.c_str());
-	
-		if (writeTerrain) {
-			f->printf("-- Tiles Map\n");
-			for (i = 0; i < map->Info.MapHeight; ++i) {
-				for (j = 0; j < map->Info.MapWidth; ++j) {
-					int tile;
-					int n;
-			
-					tile = map->Field(j, i)->Tile;
-					for (n = 0; n < map->Tileset.NumTiles && tile != map->Tileset.Table[n]; ++n) {
-					}
-					f->printf("SetTile(%3d, %d, %d)\n", n, j, i);
-				}
-			}
-		}
+		f->printf("-- patches\n");
+		f->printf("%s", Map.PatchManager.savePatches(true).c_str());
+		f->printf("\n");
 
 		f->printf("-- place units\n");
-		for (i = 0; i < NumUnits; ++i) {
-			f->printf("CreateUnit(\"%s\", ", Units[i]->Type->Ident.c_str());
-			if (Units[i]->Player->Index == PlayerMax - 1) {
-				f->printf("PlayerNumNeutral");
-			} else {
-				f->printf("%d", Units[i]->Player->Index);
-			}
-			f->printf(", {%d, %d})\n", Units[i]->X, Units[i]->Y);
-		}
+		WriteCreateUnits(f);
 		f->printf("\n\n");
 	} catch (const FileException &) {
-		fprintf(stderr,"Can't save map setup : `%s' \n", mapsetup);
+		fprintf(stderr,"Can't save map setup: `%s' \n", mapSetup);
 		delete f;
 		return -1;
 	}
@@ -278,37 +257,97 @@ int WriteMapSetup(const char *mapsetup, CMap *map, int writeTerrain)
 	return 1;
 }
 
+/**
+**  Write Lua CreateUnit calls for all existing units to the map setup
+**  file.  When the map is later loaded, these calls will recreate the
+**  units.
+**
+**  @param f     file writer for the map setup file
+*/
+static void WriteCreateUnits(FileWriter *f)
+{
+	int i;
+
+	// Hot-spot units must be created before the magma-pump units
+	// that are built on top of them.  Otherwise, the map would
+	// not be correctly loaded.
+	//
+	// When the user first adds a hot spot and a magma pump in the
+	// editor, they end up in the correct order in the Units
+	// array.  However, if the user then deletes some other unit,
+	// CUnit::Release moves the last unit in the array to the slot
+	// of the deleted unit, and this can move the magma pump in
+	// front of the hot spot.  If the units are saved in that order,
+	// and the map is then loaded, CclCreateUnit will refuse to
+	// place the hot spot on top of the magma pump, and will instead
+	// place it somewhere nearby.  This behavior of CclCreateUnit
+	// is necessary because it can be called from triggers too.
+	//
+	// Currently, magma pumps are the only unit type with any
+	// building rules, so we just check that.  This code may have
+	// to be revised if building rules are added to other unit
+	// types, especially if the rules are chained (X on top of Y
+	// on top of Z).
+	for (i = 0; i < NumUnits; ++i) {
+		if (Units[i]->Type->BuildingRules.empty()) {
+			WriteCreateUnit(f, Units[i]);
+		}
+	}
+	for (i = 0; i < NumUnits; ++i) {
+		if (!Units[i]->Type->BuildingRules.empty()) {
+			WriteCreateUnit(f, Units[i]);
+		}
+	}
+}
+
+/**
+**  Write a Lua CreateUnit call for the specified unit to the map
+**  setup file.  When the map is later loaded, this call will recreate
+**  the unit.
+**
+**  @param f     file writer for the map setup file
+**  @param unit  unit to be created when the map is loaded
+*/
+static void WriteCreateUnit(FileWriter *f, const CUnit *unit)
+{
+	f->printf("CreateUnit(\"%s\", ", unit->Type->Ident.c_str());
+	if (unit->Player->Index == PlayerMax - 1) {
+		f->printf("PlayerNumNeutral");
+	} else {
+		f->printf("%d", unit->Player->Index);
+	}
+	f->printf(", {%d, %d})\n", unit->X, unit->Y);
+}
 
 
 /**
 **  Save a Stratagus map.
 **
-**  @param mapname   map filename
-**  @param map       map to save
-**  @param writeTerrain   write the tiles map in the .sms
+**  @param mapName  map filename
+**  @param map      map to save
 */
-int SaveStratagusMap(const std::string &mapname, CMap *map, int writeTerrain)
+int SaveStratagusMap(const std::string &mapName, CMap *map)
 {
-	std::string mappresentation;
-	std::string mapsetup;
+	std::string mapPresentation;
+	std::string mapSetup;
 
 	if (!map->Info.MapWidth || !map->Info.MapHeight) {
-		fprintf(stderr, "%s: invalid Bos Wars map\n", mapname.c_str());
+		fprintf(stderr, "%s: invalid Bos Wars map\n", mapName.c_str());
 		ExitFatal(-1);
 	}
 
-	if (mapname.find(".map") == mapname.npos) {
-		fprintf(stderr, "%s: invalid Bos Wars map filename\n", mapname.c_str());
+	if (mapName.find(".map") == std::string::npos) {
+		fprintf(stderr, "%s: invalid Bos Wars map filename\n", mapName.c_str());
 	}
 
-	makedir(mapname.c_str(), 0777);
-	mappresentation = mapname + std::string("/presentation.smp");
-	mapsetup = mapname + std::string("/setup.sms");
-	if (WriteMapPresentation(mappresentation, map) == -1) {
+	makedir(mapName.c_str(), 0777);
+	mapPresentation = mapName + std::string("/presentation.smp");
+	mapSetup = mapName + std::string("/setup.sms");
+	if (WriteMapPresentation(mapPresentation, map) == -1) {
 		return -1;
 	}
 
-	return WriteMapSetup(mapsetup.c_str(), map, writeTerrain);
+	return WriteMapSetup(mapSetup.c_str(), map);
 }
 
 
@@ -556,7 +595,7 @@ void CreateGame(const std::string &filename, CMap *map)
 	}
 
 	for (i = 0; i < PlayerMax; ++i) {
-		int playertype = Map.Info.PlayerType[i];
+		PlayerTypes playertype = (PlayerTypes)Map.Info.PlayerType[i];
 		// Network games only:
 		if (GameSettings.Presets[i].Type != SettingsPresetMapDefault) {
 			playertype = GameSettings.Presets[i].Type;
@@ -646,9 +685,8 @@ void CreateGame(const std::string &filename, CMap *map)
 	InitUserInterface();
 	UI.Load();
 
-	UI.Minimap.Create();
 	Map.Init();
-	PreprocessMap();
+	UI.Minimap.Create();
 
 	//
 	// Sound part
@@ -729,7 +767,7 @@ void InitSettings(void)
 {
 	for (int i = 0; i < PlayerMax; ++i) {
 		GameSettings.Presets[i].Team = SettingsPresetMapDefault;
-		GameSettings.Presets[i].Type = SettingsPresetMapDefault;
+		GameSettings.Presets[i].Type = (PlayerTypes)SettingsPresetMapDefault;
 	}
 	GameSettings.Resources = SettingsPresetMapDefault;
 	GameSettings.NumUnits = SettingsPresetMapDefault;
