@@ -9,7 +9,7 @@
 //
 /**@name missile.cpp - The missiles. */
 //
-//      (c) Copyright 1998-2007 by Lutz Sammer and Jimmy Salmon
+//      (c) Copyright 1998-2008 by Lutz Sammer and Jimmy Salmon
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -46,7 +46,6 @@
 
 #include "video.h"
 #include "font.h"
-#include "tileset.h"
 #include "map.h"
 #include "unitsound.h"
 #include "unittype.h"
@@ -1191,7 +1190,6 @@ void CleanMissiles(void)
 	LocalMissiles.clear();
 }
 
-#ifdef DEBUG
 void FreeBurningBuildingFrames()
 {
 	for (std::vector<BurningBuildingFrame *>::iterator i = BurningBuildingFrames.begin();
@@ -1200,7 +1198,6 @@ void FreeBurningBuildingFrames()
 	}
 	BurningBuildingFrames.clear();
 }
-#endif
 
 /*----------------------------------------------------------------------------
 --    Functions (Spells Controllers/Callbacks) TODO: move to another file?
