@@ -9,7 +9,7 @@
 //
 /**@name player.cpp - The players. */
 //
-//      (c) Copyright 1998-2007 by Lutz Sammer, Jimmy Salmon, Nehal Mistry
+//      (c) Copyright 1998-2010 by Lutz Sammer, Jimmy Salmon, Nehal Mistry
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -232,9 +232,6 @@ void CPlayer::RebuildUnitsConsumingResourcesList()
 		if (unit->Orders[0]->Action == UnitActionTrain && unit->SubAction != 0) {
 			CalculateRequestedAmount(unit->Type, unit->Orders[0]->Type->ProductionCosts, costs);
 			AddToUnitsConsumingResources(unit, costs);
-		} else if (unit->Orders[0]->Action == UnitActionBuilt && !unit->Type->BuilderOutside) {
-			CalculateRequestedAmount(unit->Type, unit->Type->ProductionCosts, costs);
-			unit->Player->AddToUnitsConsumingResources(unit, costs);
 		} else if (unit->Orders[0]->Action == UnitActionRepair && unit->SubAction == 20) {
 			CalculateRequestedAmount(unit->Type, unit->Orders[0]->Goal->Type->ProductionCosts, costs);
 			AddToUnitsConsumingResources(unit, costs);
@@ -487,7 +484,7 @@ void SavePlayers(CFile *file)
 **
 **  @param type  Player type (Computer,Human,...).
 */
-void CreatePlayer(int type)
+void CreatePlayer(PlayerTypes type)
 {
 	int team;
 	int i;
@@ -654,7 +651,7 @@ void CPlayer::Clear()
 {
 	Index = 0;
 	Name.clear();
-	Type = 0;
+	Type = (PlayerTypes)0;
 	AiName.clear();
 	Team = 0;
 	Enemy = 0;
@@ -834,10 +831,24 @@ void GraphicPlayerPixels(CPlayer *player, const CGraphic *sprite)
 {
 	Assert(PlayerColorIndexCount);
 
+	if (sprite->Surface->format->palette == NULL) {
+		// Cannot set the player colors when there is no palette.
+		return;
+	}
+
+	// Skip units whose color palette does not cover the indexes
+	// for the player color.
+	if (sprite->Surface->format->palette->ncolors < PlayerColorIndexStart + PlayerColorIndexCount) {
+		return;
+	}
+
 	SDL_LockSurface(sprite->Surface);
 	SDL_SetColors(sprite->Surface, player->UnitColors.Colors,
 		PlayerColorIndexStart, PlayerColorIndexCount);
 	if (sprite->SurfaceFlip) {
+		// The flipped surface is supposed to have a similar palette.
+		Assert(sprite->SurfaceFlip->format->palette->ncolors
+		       == sprite->Surface->format->palette->ncolors);
 		SDL_SetColors(sprite->SurfaceFlip,
 			player->UnitColors.Colors, PlayerColorIndexStart, PlayerColorIndexCount);
 	}
