@@ -38,6 +38,7 @@
 #include "replay.h"
 #include "version.h"
 #include "iolib.h"
+#include "iocompat.h"
 #include "script.h"
 #include "unittype.h"
 #include "unit_manager.h"
@@ -84,11 +85,11 @@ public:
 */
 class MPPlayer {
 public:
-	MPPlayer() : Team(0), Type(0) {}
+	MPPlayer() : Team(0), Type((PlayerTypes)0) {}
 
 	std::string Name;
 	int Team;
-	int Type;
+	PlayerTypes Type;
 };
 
 /**
@@ -138,9 +139,9 @@ public:
 // Variables
 //----------------------------------------------------------------------------
 
-int CommandLogDisabled;            /// True if command log is off
+bool CommandLogDisabled;           /// True if command log is off
 ReplayType ReplayGameType;         /// Replay game type
-static int DisabledLog;            /// Disabled log for replay
+static bool DisabledLog;           /// Disabled log for replay
 static CFile *LogFile;             /// Replay log file
 static unsigned long NextLogCycle; /// Next log cycle number
 static int InitReplay;             /// Initialize replay
@@ -175,7 +176,7 @@ static FullReplay *StartReplay(void)
 
 	replay->Comment1 = "Generated by Bos Wars Version " VERSION "";
 	replay->Comment2 = "Visit http://www.boswars.org for more information";
-	replay->Comment3 = "$Id: replay.cpp 9425 2008-01-22 05:57:33Z jim4 $";
+	replay->Comment3 = "$Id: replay.cpp 9589 2009-05-30 18:09:56Z jim4 $";
 
 	if (GameSettings.NetGameType == SettingsSinglePlayerGame) {
 		replay->Type = ReplaySinglePlayer;
@@ -416,7 +417,7 @@ void CommandLog(const char *action, const CUnit *unit, int flush,
 		LogFile = new CFile;
 		if (LogFile->open(buf, CL_OPEN_WRITE) == -1) {
 			// don't retry for each command
-			CommandLogDisabled = 0;
+			CommandLogDisabled = false;
 			delete LogFile;
 			LogFile = NULL;
 			return;
@@ -582,7 +583,7 @@ static int CclReplayLog(lua_State *l)
 		} else if (!strcmp(value, "LocalPlayer")) {
 			replay->LocalPlayer = LuaToNumber(l, -1);
 		} else if (!strcmp(value, "Players")) {
-			if (!lua_istable(l, -1) || luaL_getn(l, -1) != PlayerMax) {
+			if (!lua_istable(l, -1) || lua_objlen(l, -1) != PlayerMax) {
 				LuaError(l, "incorrect argument");
 			}
 			for (j = 0; j < PlayerMax; ++j) {
@@ -601,7 +602,7 @@ static int CclReplayLog(lua_State *l)
 					} else if (!strcmp(value, "Team")) {
 						replay->Players[j].Team = LuaToNumber(l, -1);
 					} else if (!strcmp(value, "Type")) {
-						replay->Players[j].Type = LuaToNumber(l, -1);
+						replay->Players[j].Type = (PlayerTypes)LuaToNumber(l, -1);
 					} else {
 						LuaError(l, "Unsupported key: %s" _C_ value);
 					}
@@ -626,7 +627,7 @@ static int CclReplayLog(lua_State *l)
 		} else if (!strcmp(value, "MapRichness")) {
 			replay->MapRichness = LuaToNumber(l, -1);
 		} else if (!strcmp(value, "Engine")) {
-			if (!lua_istable(l, -1) || luaL_getn(l, -1) != 3) {
+			if (!lua_istable(l, -1) || lua_objlen(l, -1) != 3) {
 				LuaError(l, "incorrect argument");
 			}
 			lua_rawgeti(l, -1, 1);
@@ -639,7 +640,7 @@ static int CclReplayLog(lua_State *l)
 			replay->Engine[2] = LuaToNumber(l, -1);
 			lua_pop(l, 1);
 		} else if (!strcmp(value, "Network")) {
-			if (!lua_istable(l, -1) || luaL_getn(l, -1) != 3) {
+			if (!lua_istable(l, -1) || lua_objlen(l, -1) != 3) {
 				LuaError(l, "incorrect argument");
 			}
 			lua_rawgeti(l, -1, 1);
@@ -663,7 +664,7 @@ static int CclReplayLog(lua_State *l)
 	if (!SaveGameLoading) {
 		ApplyReplaySettings();
 	} else {
-		CommandLogDisabled = 0;
+		CommandLogDisabled = false;
 	}
 
 	return 0;
@@ -701,8 +702,8 @@ int LoadReplay(const std::string &name)
 
 	NextLogCycle = ~0UL;
 	if (!CommandLogDisabled) {
-		CommandLogDisabled = 1;
-		DisabledLog = 1;
+		CommandLogDisabled = true;
+		DisabledLog = true;
 	}
 	GameObserve = true;
 	InitReplay = 1;
@@ -739,8 +740,8 @@ void CleanReplayLog(void)
 	ReplayStep = NULL;
 
 // if (DisabledLog) {
-		CommandLogDisabled = 0;
-		DisabledLog = 0;
+		CommandLogDisabled = false;
+		DisabledLog = false;
 // }
 	GameObserve = false;
 	NetPlayers = 0;
