@@ -68,7 +68,7 @@ static void CclSpellMissileLocation(lua_State *l, SpellActionMissileLocation *lo
 	if (!lua_istable(l, -1)) {
 		LuaError(l, "incorrect argument");
 	}
-	args = luaL_getn(l, -1);
+	args = lua_objlen(l, -1);
 	j = 0;
 
 	for (j = 0; j < args; ++j) {
@@ -123,7 +123,7 @@ static SpellActionType *CclSpellAction(lua_State *l)
 	if (!lua_istable(l, -1)) {
 		LuaError(l, "incorrect argument");
 	}
-	args = luaL_getn(l, -1);
+	args = lua_objlen(l, -1);
 	j = 0;
 
 	lua_rawgeti(l, -1, j + 1);
@@ -521,7 +521,7 @@ static void CclSpellCondition(lua_State *l, ConditionInfo *condition)
 	if (!lua_istable(l, -1)) {
 		LuaError(l, "incorrect argument");
 	}
-	args = luaL_getn(l, -1);
+	args = lua_objlen(l, -1);
 	for (j = 0; j < args; ++j) {
 		lua_rawgeti(l, -1, j + 1);
 		value = LuaToString(l, -1);
@@ -601,7 +601,7 @@ static void CclSpellAutocast(lua_State *l, AutoCastInfo *autocast)
 	if (!lua_istable(l, -1)) {
 		LuaError(l, "incorrect argument");
 	}
-	args = luaL_getn(l, -1);
+	args = lua_objlen(l, -1);
 	for (j = 0; j < args; ++j) {
 		lua_rawgeti(l, -1, j + 1);
 		value = LuaToString(l, -1);
@@ -639,7 +639,6 @@ static int CclDefineSpell(lua_State *l)
 	SpellType *spell;
 	const char *value;
 	int args;
-	int i;
 
 	args = lua_gettop(l);
 	identname = LuaToString(l, 1);
@@ -666,7 +665,7 @@ static int CclDefineSpell(lua_State *l)
 		}
 		SpellTypeTable.push_back(spell);
 	}
-	for (i = 1; i < args; ++i) {
+	for (int i = 1; i < args; ++i) {
 		value = LuaToString(l, i + 1);
 		++i;
 		if (!strcmp(value, "showname")) {
@@ -705,7 +704,7 @@ static int CclDefineSpell(lua_State *l)
 			if (!lua_istable(l, i + 1)) {
 				LuaError(l, "incorrect argument");
 			}
-			subargs = luaL_getn(l, i + 1);
+			subargs = lua_objlen(l, i + 1);
 			for (k = 0; k < subargs; ++k) {
 				lua_rawgeti(l, i + 1, k + 1);
 				spell->Action.push_back(CclSpellAction(l));
