@@ -9,7 +9,7 @@
 //
 /**@name selection.cpp - The units' selection. */
 //
-//      (c) Copyright 1999-2007 by Patrice Fortier, Lutz Sammer, and
+//      (c) Copyright 1999-2008 by Patrice Fortier, Lutz Sammer, and
 //                                 Jimmy Salmon
 //
 //      This program is free software; you can redistribute it and/or modify
@@ -45,7 +45,6 @@
 #include "unit_cache.h"
 #include "interface.h"
 #include "map.h"
-#include "tileset.h"
 #include "ui.h"
 #include "commands.h"
 #include "network.h"
@@ -276,7 +275,7 @@ void UnSelectUnit(CUnit *unit)
 	if (unit->TeamSelected) {
 		for (i = 0; i < PlayerMax; ++i) {
 			if (unit->TeamSelected & (1 << i)) {
-				for (j = 0; TeamSelected[i][j] != unit; ++i) {
+				for (j = 0; TeamSelected[i][j] != unit; ++j) {
 					;
 				}
 				Assert(j < TeamNumSelected[i]);
@@ -1164,7 +1163,7 @@ static int CclSelection(lua_State *l)
 	InitSelections();
 	NumSelected = LuaToNumber(l, 1);
 	i = 0;
-	args = luaL_getn(l, 2);
+	args = lua_objlen(l, 2);
 	for (j = 0; j < args; ++j) {
 		const char *str;
 
