@@ -103,6 +103,7 @@ namespace gcn
         
         mCurrentFont = NULL;
         mWidgets.push_back(this); 
+        mDirty = true;
     }
 
     Widget::~Widget()
@@ -450,6 +451,7 @@ namespace gcn
                       (*iter)->mouseWheelDown(x, y);
                   }
               }
+              setDirty(true);
               break;
 
           case MouseInput::RELEASE:
@@ -486,6 +488,7 @@ namespace gcn
                   mClickCount = 0;
                   mClickTimeStamp = 0;
               }
+              setDirty(true);
               break;
         }    
     }
@@ -540,6 +543,7 @@ namespace gcn
         }
 
         mHasMouse = true;
+		setDirty(true);
 
         MouseListenerIterator iter;
         for (iter = mMouseListeners.begin(); iter != mMouseListeners.end(); ++iter)
@@ -551,6 +555,7 @@ namespace gcn
     void Widget::_mouseOutMessage()
     {
         mHasMouse = false;
+		setDirty(true);
 
         MouseListenerIterator iter;
         for (iter = mMouseListeners.begin(); iter != mMouseListeners.end(); ++iter)
@@ -741,4 +746,14 @@ namespace gcn
 
         return mFocusHandler->getModalFocused() == this;
     }
+
+    void Widget::setDirty(bool dirty)
+    {
+        mDirty = dirty;
+    }
+
+    bool Widget::getDirty() const
+    {
+        return mDirty;
+    }
 }
