@@ -453,9 +453,6 @@ public:
 /// SoundConfig PlacementError;         /// played on placements errors
 /// SoundConfig PlacementSuccess;       /// played on placements success
 /// SoundConfig Click;                  /// click noice used often
-
-	CGraphic *VictoryBackgroundG;       /// Victory background graphic
-	CGraphic *DefeatBackgroundG;        /// Defeat background graphic
 };
 
 /*----------------------------------------------------------------------------
@@ -512,6 +509,8 @@ extern void CycleViewportMode(int);
 	/// Select viewport mode
 extern void SetViewportMode(ViewportModeType mode);
 
+	/// Use the mouse to scroll the map
+extern void MouseScrollMap(int x, int y);
 	/// Check if mouse scrolling is enabled
 extern bool GetMouseScroll(void);
 	/// Enable/disable scrolling with the mouse
