@@ -162,8 +162,15 @@
 **  CUnit::IX CUnit::IY
 **
 **  Coordinate displacement in pixels or coordinates inside a tile.
-**  Currently only !=0, if the unit is moving from one tile to
-**  another (0-32 and for ships/flyers 0-64).
+**  Can be !=0 for two reasons:
+**
+**  (1) If the unit is moving from one tile to an adjacent one.
+**      CUnit::IX is then between -::TileSizeX and +::TileSizeX,
+**      and counts towards 0 during horizontal motion.
+**      CUnit::IY is similar.
+**
+**  (2) In air and sea units floating in place, CUnit::IY flickers
+**      randomly between 0 and 1.
 **
 **  CUnit::Frame
 **
@@ -647,7 +654,6 @@ public:
 		char Path[MAX_PATH_LENGTH]; /// directions of stored path
 	} Move; /// ActionMove,...
 	struct _order_built_ {
-		CUnit *Worker;              /// Worker building this unit
 		int Progress;               /// Progress counter, in 1/100 cycles.
 		int Cancel;                 /// Cancel construction
 		CConstructionFrame *Frame;  /// Construction frame
@@ -856,7 +862,7 @@ extern bool UnitHoldsResources(const CUnit *unit);
 	/// Find resource
 extern CUnit *UnitFindResource(const CUnit *unit, int x, int y, int range, int resource = -1);
 	/// Find the next idle worker
-extern CUnit *FindIdleWorker(const CPlayer *player, const CUnit *last);
+extern CUnit *FindIdleWorker(const CPlayer *player);
 
 	/// @todo more docu
 extern CUnit *UnitOnScreen(int x, int y);
