@@ -9,7 +9,7 @@
 //
 /**@name astar.cpp - The a* path finder routines. */
 //
-//      (c) Copyright 1999-2007 by Lutz Sammer, Fabrice Rossi, Russell Smith,
+//      (c) Copyright 1999-2009 by Lutz Sammer, Fabrice Rossi, Russell Smith,
 //                                 Francois Beerten, Jimmy Salmon.
 //
 //      This program is free software; you can redistribute it and/or modify
@@ -34,6 +34,10 @@
 ----------------------------------------------------------------------------*/
 
 #include "stratagus.h"
+
+#include <stdlib.h>
+#include <stdio.h>
+
 #include "pathfinder.h"
 
 /*----------------------------------------------------------------------------
