@@ -40,6 +40,7 @@
 
 #include "unittype.h"
 #include "iolib.h"
+#include "iocompat.h"
 #include "script.h"
 #include "missile.h"
 #include "upgrade.h"
@@ -60,11 +61,6 @@
 #include "player.h"
 #include "replay.h"
 
-// Workaround for the subtle change in name from lua 5.0 to lua 5.1.
-#if LUA_VERSION_NUM < 501
-#define luaL_Reg luaL_reg
-#endif
-
 /*----------------------------------------------------------------------------
 --  Variables
 ----------------------------------------------------------------------------*/
@@ -440,7 +436,6 @@ bool LuaToBoolean(lua_State *l, int narg)
 */
 void CclGarbageCollect(int fast)
 {
-#if LUA_VERSION_NUM >= 501
 	DebugPrint("Garbage collect (before): %d\n" _C_
 		lua_gc(Lua, LUA_GCCOUNT, 0));
 
@@ -448,15 +443,6 @@ void CclGarbageCollect(int fast)
 
 	DebugPrint("Garbage collect (after): %d\n" _C_
 		lua_gc(Lua, LUA_GCCOUNT, 0));
-#else
-	DebugPrint("Garbage collect (before): %d/%d\n" _C_
-		lua_getgccount(Lua) _C_ lua_getgcthreshold(Lua));
-
-	lua_setgcthreshold(Lua, 0);
-
-	DebugPrint("Garbage collect (after): %d/%d\n" _C_
-		lua_getgccount(Lua) _C_ lua_getgcthreshold(Lua));
-#endif
 }
 
 /*............................................................................
@@ -724,7 +710,8 @@ static int CclGetCompileFeature(lua_State *l)
 /**
 **  Send command to ccl.
 **
-**  @param command  Zero terminated command string.
+**  @param command      Zero terminated command string.
+**  @param exitOnError  Exit if an error occurs.
 */
 int CclCommand(const std::string &command, bool exitOnError)
 {
@@ -762,20 +749,12 @@ static void InitLua()
 		{NULL, NULL}
 	};
 
-#if LUA_VERSION_NUM >= 501
 	Lua = luaL_newstate();
-#else
-	Lua = lua_open();
-#endif
 
 	for (const luaL_Reg *lib = lualibs; lib->func; ++lib) {
-#if LUA_VERSION_NUM >= 501
 		lua_pushcfunction(Lua, lib->func);
 		lua_pushstring(Lua, lib->name);
 		lua_call(Lua, 1, 0);
-#else
-		lib->func(Lua);
-#endif
 	}
 
 	tolua_stratagus_open(Lua);
@@ -818,7 +797,6 @@ void InitCcl(void)
 	IconCclRegister();
 	MissileCclRegister();
 	PlayerCclRegister();
-	TilesetCclRegister();
 	MapCclRegister();
 	ConstructionCclRegister();
 	DecorationCclRegister();
@@ -832,8 +810,6 @@ void InitCcl(void)
 	AiCclRegister();
 	TriggerCclRegister();
 	SpellCclRegister();
-
-	EditorCclRegister();
 }
 
 static char *LuaEscape(const char *str)
@@ -1039,13 +1015,15 @@ void CreateUserDirectories(void)
 	std::string directory;
 	UserDirectory = "";
 
-#ifndef USE_WIN32
 	std::string s;
+#ifdef USE_WIN32
+	s = getenv("APPDATA");
+#else
 	s = getenv("HOME");
+#endif
 	if (!s.empty()) {
 		UserDirectory = s + "/";
 	}
-#endif
 	
 	UserDirectory += STRATAGUS_HOME_PATH;
 	makedir(UserDirectory.c_str(), 0777);
@@ -1055,6 +1033,8 @@ void CreateUserDirectories(void)
 	makedir(directory.c_str(), 0777);
 	directory = UserDirectory + "save/";
 	makedir(directory.c_str(), 0777);
+	directory = UserDirectory + "patches/";
+	makedir(directory.c_str(), 0777);
 }
 
 /**
