@@ -9,7 +9,7 @@
 //
 /**@name stratagus.cpp - The main file. */
 //
-//      (c) Copyright 1998-2008 by Lutz Sammer, Francois Beerten, and
+//      (c) Copyright 1998-2010 by Lutz Sammer, Francois Beerten, and
 //                                 Jimmy Salmon
 //
 //      This program is free software; you can redistribute it and/or modify
@@ -55,7 +55,7 @@
 **
 ** Handles the map. A map is made from tiles.
 **
-** @see map.h @see map.cpp @see tileset.h @see tileset.cpp
+** @see map.h @see map.cpp
 **
 ** @subsection Unit Unit
 **
@@ -143,9 +143,6 @@
 ** This is the integrated editor, it shouldn't be a perfect
 ** editor. It is used to test new features of the engine.
 **
-** See page @ref EditorModule for more information upon supported
-** features and API.
-**
 ** @see editor.h @see editor.cpp
 */
 
@@ -160,6 +157,7 @@
 #include <time.h>
 #include <ctype.h>
 #include <sstream>
+#include <algorithm>
 
 #ifndef _MSC_VER
 #include <unistd.h>
@@ -205,6 +203,7 @@ extern int getopt(int argc, char *const *argv, const char *opt);
 #include "widgets.h"
 #include "trigger.h"
 #include "iolib.h"
+#include "iocompat.h"
 #include "guichan.h"
 #include "version.h"
 #include "title.h"
@@ -226,7 +225,7 @@ std::string LocalPlayerName;         /// Name of local player
 
 	/// Name, Version, Copyright
 static std::string NameLine =
-	"Bos Wars V" VERSION ", (c) 1998-2008 by the Bos Wars and Stratagus Project.";
+	"Bos Wars V" VERSION ", (c) 1998-2010 by the Bos Wars and Stratagus Project.";
 
 std::string CliMapName;          /// Filename of the map given on the command line
 std::string CompileOptions;          /// Compile options.
@@ -352,7 +351,6 @@ void CleanGame(void)
 	CleanSelections();
 	CleanGroups();
 	CleanMissiles();
-	CleanTilesets();
 	Map.Clean();
 	CleanReplayLog();
 	FreeVisionTable();
@@ -420,9 +418,10 @@ void StartSavedGame(const std::string &filename)
 	ExpandPath(path, filename);
 	LoadGame(path);
 
-	StartMap(filename, false);
+	// the filename argument of StartMap is unused with saved games
+	StartMap("", false);
 }
-	
+
 void StartReplay(const std::string &filename, bool reveal)
 {
 	std::string replay;
@@ -572,11 +571,15 @@ void Exit(int err)
 	NetworkQuit();
 
 	ExitNetwork1();
-#ifdef DEBUG
+	
 	CleanModules();
 	FreeBurningBuildingFrames();
-	FreeSounds();
+	// FreeGraphics must be called before exit to avoid the static 
+	// deinitialization fiasco.
 	FreeGraphics();
+	
+#ifdef DEBUG
+	FreeSounds();
 	FreePlayerColors();
 	FreeButtonStyles();
 	for (size_t i = 0; i < Containers.size(); ++i) {
@@ -590,7 +593,7 @@ void Exit(int err)
 	lua_close(Lua);
 #endif
 
-	fprintf(stdout, _("Thanks for playing Bos Wars.\n"));
+	fputs(_("Thanks for playing Bos Wars.\n"), stdout);
 	exit(err);
 }
 
@@ -621,7 +624,6 @@ static void Usage(void)
 		\t-n server\tNetwork server host preset\n\
 		\t-L lag\t\tNetwork lag in # frames (default 10 = 333ms)\n\
 		\t-U update\tNetwork update rate in # frames (default 5=6x per s)\n\
-		\t-s sleep\tNumber of frames for the AI to sleep before it starts\n\
 		\t-v mode\t\tVideo mode (0=default,1=640x480,2=800x600,\n\
 		\t\t\t\t3=1024x768,4=1280x960,5=1600x1200)\n\
 		\t-D\t\tVideo mode depth = pixel per point (for Win32/TNT)\n\
@@ -739,24 +741,21 @@ int main(int argc, char **argv)
 	//  Parse commandline
 	//
 	for (;;) {
-		switch (getopt(argc, argv, "c:d:hln:P:s:v:D:N:E:FL:S:U:W?")) {
+		switch (getopt(argc, argv, "c:d:hln:P:v:D:N:E:FL:S:U:W?")) {
 			case 'c':
 				CclStartFile = optarg;
 				continue;
 			case 'd':
 			{
 				StratagusLibPath = optarg;
-				size_t index;
-				while ((index = StratagusLibPath.find('\\')) != std::string::npos) {
-					StratagusLibPath[index] = '/';
-				}
+				replace(StratagusLibPath.begin(), StratagusLibPath.end(), '\\', '/');
 				continue;
 			}
 			case 'E':
 				EditorStartFile = optarg;
 				continue;
 			case 'l':
-				CommandLogDisabled = 1;
+				CommandLogDisabled = true;
 				continue;
 			case 'P':
 				NetworkPort = atoi(optarg);
@@ -767,9 +766,6 @@ int main(int argc, char **argv)
 			case 'N':
 				LocalPlayerName = optarg;
 				continue;
-			case 's':
-				AiSleepCycles = atoi(optarg);
-				continue;
 			case 'v':
 				switch (atoi(optarg)) {
 					case 0:
@@ -845,11 +841,8 @@ int main(int argc, char **argv)
 	}
 
 	if (argc - optind) {
-		size_t index;
 		CliMapName = argv[optind];
-		while ((index = CliMapName.find('\\')) != std::string::npos) {
-			CliMapName[index] = '/';
-		}
+		replace(CliMapName.begin(), CliMapName.end(), '\\', '/');
 		--argc;
 	}
 
