@@ -48,7 +48,7 @@
 #include "ui.h"
 #include "menus.h"
 #include "script.h"
-#include "tileset.h"
+#include "map.h"
 #include "minimap.h"
 #include "network.h"
 #include "font.h"
@@ -431,12 +431,9 @@ static void UiToggleTerrain(void)
 static void UiFindIdleWorker(void)
 {
 	CUnit *unit;
-	// FIXME: static variable, is not needed.
-	static CUnit *LastIdleWorker = NoUnitP;
 
-	unit = FindIdleWorker(ThisPlayer, LastIdleWorker);
+	unit = FindIdleWorker(ThisPlayer);
 	if (unit != NoUnitP) {
-		LastIdleWorker = unit;
 		SelectSingleUnit(unit);
 		UI.StatusLine.Clear();
 		ClearCosts();
@@ -749,7 +746,6 @@ int HandleCheats(const std::string &input)
 static int InputKey(int key)
 {
 	char ChatMessage[sizeof(Input) + 40];
-	int i;
 	char *namestart;
 	char *p;
 	char *q;
@@ -838,7 +834,7 @@ static int InputKey(int key)
 			if (!strlen(namestart)) {
 				return 1;
 			}
-			for (i = 0; i < PlayerMax; ++i) {
+			for (int i = 0; i < PlayerMax; ++i) {
 				if (Players[i].Type != PlayerPerson) {
 					continue;
 				}
