@@ -9,7 +9,7 @@
 //
 /**@name mainscr.cpp - The main screen. */
 //
-//      (c) Copyright 1998-2007 by Lutz Sammer, Valery Shchedrin, and
+//      (c) Copyright 1998-2008 by Lutz Sammer, Valery Shchedrin, and
 //                                 Jimmy Salmon
 //
 //      This program is free software; you can redistribute it and/or modify
@@ -53,7 +53,6 @@
 #include "interface.h"
 #include "ui.h"
 #include "map.h"
-#include "tileset.h"
 #include "trigger.h"
 #include "network.h"
 #include "menus.h"
@@ -343,13 +342,13 @@ static void DrawUnitInfo(CUnit *unit)
 	//
 	if (NumSelected == 1 && Selected[0] == unit) {
 		// Training units.
-		if (unit->Orders[0]->Action == UnitActionTrain) {
+		if (!isEnemy && unit->Orders[0]->Action == UnitActionTrain) {
 			DrawTrainingUnits(unit);
 			return;
 		}
 
 		// Transporting units.
-		if (unit->Type->CanTransport && unit->BoardCount) {
+		if (!isEnemy && unit->Type->CanTransport && unit->BoardCount) {
 			DrawTransportingUnits(unit);
 			return;
 		}
@@ -793,8 +792,9 @@ void DrawCosts(void)
 {
 	int x = UI.StatusLine.TextX + 268;
 	if (CostsMana) {
-		// FIXME: hardcoded image!!!
-		UI.Resources[EnergyCost].G->DrawFrameClip(3, x, UI.StatusLine.TextY);
+		if (UI.Resources[EnergyCost].G->NumFrames >= 3) {
+			UI.Resources[EnergyCost].G->DrawFrameClip(2, x, UI.StatusLine.TextY);
+		}
 
 		VideoDrawNumber(x + 15, UI.StatusLine.TextY, GameFont, CostsMana);
 		x += 60;
