@@ -9,7 +9,7 @@
 //
 /**@name mouse.cpp - The mouse handling. */
 //
-//      (c) Copyright 1998-2007 by Lutz Sammer and Jimmy Salmon
+//      (c) Copyright 1998-2009 by Lutz Sammer and Jimmy Salmon
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -40,7 +40,6 @@
 #include <ctype.h>
 
 #include "stratagus.h"
-#include "tileset.h"
 #include "video.h"
 #include "map.h"
 #include "sound.h"
@@ -579,12 +578,6 @@ void HandleMouseExit(void)
 
 	// Prevent scrolling while out of focus (on other applications) */
 	KeyScrollState = MouseScrollState = ScrollNone;
-
-	// Show hour-glass (to denote to the user, the game is waiting)
-	// FIXME: couldn't define a hour-glass that easily, so used pointer
-	CursorX = Video.Width / 2;
-	CursorY = Video.Height / 2;
-	GameCursor = UI.Point.Cursor;
 }
 
 /**
@@ -639,6 +632,29 @@ void RestrictCursorToMinimap(void)
 	CursorOn = CursorOnMinimap;
 }
 
+/**
+**  Use the mouse to scroll the map
+**
+**  @param x  Screen X position.
+**  @param y  Screen Y position.
+*/
+void MouseScrollMap(int x, int y)
+{
+	int speed;
+
+	if (KeyModifiers & ModifierControl) {
+		speed = UI.MouseScrollSpeedControl;
+	} else {
+		speed = UI.MouseScrollSpeedDefault;
+	}
+
+	UI.MouseViewport->Set(UI.MouseViewport->MapX, UI.MouseViewport->MapY,
+		UI.MouseViewport->OffsetX + speed * (x - CursorStartX),
+		UI.MouseViewport->OffsetY + speed * (y - CursorStartY));
+	UI.MouseWarpX = CursorStartX;
+	UI.MouseWarpY = CursorStartY;
+}
+
 /**
 **  Handle movement of the cursor.
 **
@@ -676,19 +692,7 @@ void UIHandleMouseMove(int x, int y)
 	//  Move map.
 	//
 	if (GameCursor == UI.Scroll.Cursor) {
-		int speed;
-
-		if (KeyModifiers & ModifierControl) {
-			speed = UI.MouseScrollSpeedControl;
-		} else {
-			speed = UI.MouseScrollSpeedDefault;
-		}
-
-		UI.MouseViewport->Set(UI.MouseViewport->MapX, UI.MouseViewport->MapY,
-			UI.MouseViewport->OffsetX + speed * (x - CursorStartX),
-			UI.MouseViewport->OffsetY + speed * (y - CursorStartY));
-		UI.MouseWarpX = CursorStartX;
-		UI.MouseWarpY = CursorStartY;
+		MouseScrollMap(x, y);
 		return;
 	}
 
@@ -1294,7 +1298,6 @@ void UIHandleButtonDown(unsigned button)
 	static bool OldShowAttackRange;
 	static bool OldValid = false;
 	CUnit *uins;
-	int i;
 
 /**
 **  Detect long selection click, FIXME: tempory hack to test the feature.
@@ -1533,7 +1536,7 @@ void UIHandleButtonDown(unsigned button)
 						ThisPlayer->IsTeamed(Selected[0])) {
 					if (Selected[0]->BoardCount >= ButtonUnderCursor) {
 						uins = Selected[0]->UnitInside;
-						for (i = ButtonUnderCursor; i; uins = uins->NextContained) {
+						for (int i = ButtonUnderCursor; i; uins = uins->NextContained) {
 							if (uins->Boarded) {
 								--i;
 							}
@@ -1775,9 +1778,8 @@ void UIHandleButtonUp(unsigned button)
 							Selected[0]->Player->UnitTypesCount[Selected[0]->Type->Slot],
 							Selected[0]->Type->Name.c_str());
 					} else {
-						sprintf_s(buf, sizeof(buf), _("You have ~<%d~> %s(s)"),
-							Selected[0]->Player->UnitTypesCount[Selected[0]->Type->Slot],
-							Selected[0]->Type->Name.c_str());
+						sprintf_s(buf, sizeof(buf), _("You have ~<1~> %s"),
+						        Selected[0]->Type->Name.c_str());
 					}
 					UI.StatusLine.Set(buf);
 				}
