@@ -110,6 +110,7 @@ void initGuichan()
 	Gui->setGraphics(graphics);
 	Gui->setInput(Input);
 	Gui->setTop(NULL);
+	Gui->setUseDirtyDrawing(!UseOpenGL);
 
 	GuichanCallbacks.ButtonPressed = &MenuHandleButtonDown;
 	GuichanCallbacks.ButtonReleased = &MenuHandleButtonUp;
@@ -159,6 +160,7 @@ void handleInput(const SDL_Event *event)
 void DrawGuichanWidgets() 
 {
 	if (Gui) {
+		Gui->setUseDirtyDrawing(!UseOpenGL && !GameRunning && !Editor.Running && !PatchEditorRunning);
 		Gui->draw();
 	}
 }
@@ -775,6 +777,7 @@ void MultiLineLabel::setCaption(const std::string &caption)
 {
 	this->mCaption = caption;
 	this->wordWrap();
+	this->setDirty(true);
 }
 
 /**
@@ -1050,6 +1053,7 @@ void ScrollingWidget::add(gcn::Widget *widget, int x, int y)
 */
 void ScrollingWidget::logic()
 {
+	setDirty(true);
 	if (container.getHeight() + containerY - speedY > 0 ) {
 		// the bottom of the container is lower than the top 
 		// of the widget. It is thus still visible.
@@ -1219,7 +1223,7 @@ void LuaListModel::setList(lua_State *lua, lua_Object *lo)
 
 	list.clear();
 
-	args = luaL_getn(lua, *lo);
+	args = lua_objlen(lua, *lo);
 	for (j = 0; j < args; ++j) {
 		lua_rawgeti(lua, *lo, j + 1);
 		list.push_back(std::string(LuaToString(lua, -1)));
@@ -1423,6 +1427,7 @@ void StatBoxWidget::draw(gcn::Graphics *graphics)
 void StatBoxWidget::setCaption(const std::string &caption)
 {
 	this->caption = caption;
+	this->setDirty(true);
 }
 
 /**
@@ -1441,6 +1446,7 @@ const std::string &StatBoxWidget::getCaption() const
 */
 void StatBoxWidget::setPercent(const int percent)
 {
+	this->setDirty(true);
 	this->percent = percent;
 }
 
