@@ -37,7 +37,6 @@
 
 #include "stratagus.h"
 #include "video.h"
-#include "tileset.h"
 #include "map.h"
 #include "sound.h"
 #include "unitsound.h"
@@ -123,7 +122,7 @@ static void ParseBuildingRules(lua_State *l, std::vector<CBuildRestriction *> &b
 	int args;
 	CBuildRestrictionAnd *andlist = new CBuildRestrictionAnd();
 
-	args = luaL_getn(l, -1);
+	args = lua_objlen(l, -1);
 	Assert(!(args & 1)); // must be even
 
 	for (int i = 0; i < args; ++i) {
@@ -253,7 +252,7 @@ static int CclDefineUnitType(lua_State *l)
 			if (!lua_istable(l, -1)) {
 				LuaError(l, "incorrect argument");
 			}
-			subargs = luaL_getn(l, -1);
+			subargs = lua_objlen(l, -1);
 			for (k = 0; k < subargs; ++k) {
 				lua_rawgeti(l, -1, k + 1);
 				value = LuaToString(l, -1);
@@ -284,7 +283,7 @@ static int CclDefineUnitType(lua_State *l)
 			if (!lua_istable(l, -1)) {
 				LuaError(l, "incorrect argument");
 			}
-			subargs = luaL_getn(l, -1);
+			subargs = lua_objlen(l, -1);
 			for (k = 0; k < subargs; ++k) {
 				lua_rawgeti(l, -1, k + 1);
 				value = LuaToString(l, -1);
@@ -324,7 +323,7 @@ static int CclDefineUnitType(lua_State *l)
 				}
 			}
 		} else if (!strcmp(value, "Offset")) {
-			if (!lua_istable(l, -1) || luaL_getn(l, -1) != 2) {
+			if (!lua_istable(l, -1) || lua_objlen(l, -1) != 2) {
 				LuaError(l, "incorrect argument");
 			}
 			lua_rawgeti(l, -1, 1);
@@ -402,7 +401,7 @@ static int CclDefineUnitType(lua_State *l)
 			type->Variable[MANA_INDEX].Increase = 1;
 			type->Variable[MANA_INDEX].Enable = 1;
 		} else if (!strcmp(value, "TileSize")) {
-			if (!lua_istable(l, -1) || luaL_getn(l, -1) != 2) {
+			if (!lua_istable(l, -1) || lua_objlen(l, -1) != 2) {
 				LuaError(l, "incorrect argument");
 			}
 			lua_rawgeti(l, -1, 1);
@@ -414,7 +413,7 @@ static int CclDefineUnitType(lua_State *l)
 		} else if (!strcmp(value, "Decoration")) {
 			type->Decoration = LuaToBoolean(l, -1);
 		} else if (!strcmp(value, "NeutralMinimapColor")) {
-			if (!lua_istable(l, -1) || luaL_getn(l, -1) != 3) {
+			if (!lua_istable(l, -1) || lua_objlen(l, -1) != 3) {
 				LuaError(l, "incorrect argument");
 			}
 			lua_rawgeti(l, -1, 1);
@@ -427,7 +426,7 @@ static int CclDefineUnitType(lua_State *l)
 			type->NeutralMinimapColorRGB.b = LuaToNumber(l, -1);
 			lua_pop(l, 1);
 		} else if (!strcmp(value, "BoxSize")) {
-			if (!lua_istable(l, -1) || luaL_getn(l, -1) != 2) {
+			if (!lua_istable(l, -1) || lua_objlen(l, -1) != 2) {
 				LuaError(l, "incorrect argument");
 			}
 			lua_rawgeti(l, -1, 1);
@@ -534,7 +533,7 @@ static int CclDefineUnitType(lua_State *l)
 			if (!lua_istable(l, -1)) {
 				LuaError(l, "incorrect argument");
 			}
-			subargs = luaL_getn(l, -1);
+			subargs = lua_objlen(l, -1);
 			// Free any old restrictions if they are redefined
 			for (std::vector<CBuildRestriction *>::iterator b = type->BuildingRules.begin();
 					b != type->BuildingRules.end(); ++b) {
@@ -549,10 +548,6 @@ static int CclDefineUnitType(lua_State *l)
 				ParseBuildingRules(l, type->BuildingRules);
 				lua_pop(l, 1);
 			}
-		} else if (!strcmp(value, "BuilderOutside")) {
-			type->BuilderOutside = LuaToBoolean(l, -1);
-		} else if (!strcmp(value, "BuilderLost")) {
-			type->BuilderLost = LuaToBoolean(l, -1);
 		} else if (!strcmp(value, "ShoreBuilding")) {
 			type->ShoreBuilding = LuaToBoolean(l, -1);
 		} else if (!strcmp(value, "LandUnit")) {
@@ -589,7 +584,7 @@ static int CclDefineUnitType(lua_State *l)
 				type->CanCastSpell = new char[SpellTypeTable.size()];
 				memset(type->CanCastSpell, 0, SpellTypeTable.size() * sizeof(char));
 			}
-			subargs = luaL_getn(l, -1);
+			subargs = lua_objlen(l, -1);
 			if (subargs == 0) {
 				delete[] type->CanCastSpell;
 				type->CanCastSpell = NULL;
@@ -619,7 +614,7 @@ static int CclDefineUnitType(lua_State *l)
 				type->AutoCastActive = new char[SpellTypeTable.size()];
 				memset(type->AutoCastActive, 0, SpellTypeTable.size() * sizeof(char));
 			}
-			subargs = luaL_getn(l, -1);
+			subargs = lua_objlen(l, -1);
 			if (subargs == 0) {
 				delete[] type->AutoCastActive;
 				type->AutoCastActive = NULL;
@@ -652,7 +647,7 @@ static int CclDefineUnitType(lua_State *l)
 			if (!lua_istable(l, -1)) {
 				LuaError(l, "incorrect argument");
 			}
-			subargs = luaL_getn(l, -1);
+			subargs = lua_objlen(l, -1);
 			for (k = 0; k < subargs; ++k) {
 				lua_rawgeti(l, -1, k + 1);
 				value = LuaToString(l, -1);
@@ -933,7 +928,7 @@ static CAnimation *ParseAnimation(lua_State *l, int idx)
 	if (!lua_istable(l, idx)) {
 		LuaError(l, "incorrect argument");
 	}
-	args = luaL_getn(l, idx);
+	args = lua_objlen(l, idx);
 	anim = new CAnimation[args + 1];
 	tail = NULL;
 	Labels.clear();
@@ -1250,11 +1245,10 @@ static int CclDefineDecorations(lua_State *l)
 */
 void UpdateUnitVariables(const CUnit *unit)
 {
-	int i;
 	const CUnitType *type; // unit->Type.
 
 	type = unit->Type;
-	for (i = 0; i < NVARALREADYDEFINED; i++) { // default values
+	for (int i = 0; i < NVARALREADYDEFINED; i++) { // default values
 		if (i == ARMOR_INDEX || i == PIERCINGDAMAGE_INDEX ||
 				i == BASICDAMAGE_INDEX || i == MANA_INDEX ||
 				i == KILL_INDEX || i == HP_INDEX) {
@@ -1332,7 +1326,7 @@ void UpdateUnitVariables(const CUnit *unit)
 	unit->Variable[SLOT_INDEX].Value = unit->Slot;
 	unit->Variable[SLOT_INDEX].Max = UnitSlotFree - 1;
 
-	for (i = 0; i < NVARALREADYDEFINED; i++) { // default values
+	for (int i = 0; i < NVARALREADYDEFINED; i++) { // default values
 		unit->Variable[i].Enable &= unit->Variable[i].Max > 0;
 #ifdef DEBUG
 		if (unit->Variable[i].Value > unit->Variable[i].Max) {
