@@ -48,7 +48,6 @@
 #include "unittype.h"
 #include "animation.h"
 #include "player.h"
-#include "tileset.h"
 #include "map.h"
 #include "actions.h"
 #include "sound_server.h"
@@ -83,6 +82,7 @@ static int HelpMeLastY;                   /// Last Y coordinate HelpMe sound pla
 ----------------------------------------------------------------------------*/
 
 static void RemoveUnitFromContainer(CUnit *unit);
+static void UnitRemoveProductionAndStorage(CUnit *unit);
 
 /**
 **  Increase a unit's reference count.
@@ -808,12 +808,15 @@ void UpdateForNewUnit(const CUnit *unit, int upgrade)
 	const CUnitType *type = unit->Type;
 	CPlayer *player = unit->Player;
 
-	//
-	// Update resources
-	//
-	for (int u = 0; u < MaxCosts; ++u) {
-		player->ProductionRate[u] += type->ProductionRate[u] * unit->ProductionEfficiency / 100;
-		player->StorageCapacity[u] += type->StorageCapacity[u];
+	// Update resources.  Until the unit has been fully built, it
+	// does not produce any resources or provide storage capacity.
+	// There is a corresponding check in UnitRemoveProductionAndStorage,
+	// which subtracts them back out.
+	if (unit->Orders[0]->Action != UnitActionBuilt) {
+		for (int u = 0; u < MaxCosts; ++u) {
+			player->ProductionRate[u] += type->ProductionRate[u] * unit->ProductionEfficiency / 100;
+			player->StorageCapacity[u] += type->StorageCapacity[u];
+		}
 	}
 }
 
@@ -867,7 +870,11 @@ static void UnitFillSeenValues(CUnit *unit)
 	}
 	unit->Seen.Type = unit->Type;
 	unit->Seen.Constructed = unit->Constructed;
-	unit->Seen.CFrame = unit->Data.Built.Frame;
+	if (unit->Orders[0]->Action == UnitActionBuilt) {
+		unit->Seen.CFrame = unit->Data.Built.Frame;
+	} else {
+		unit->Seen.CFrame = NULL;
+	}
 }
 
 /**
@@ -1243,6 +1250,9 @@ void CUnit::ChangeOwner(CPlayer *newplayer)
 	int i;
 	CUnit *uins;
 	CPlayer *oldplayer;
+	int requestedCosts[MaxCosts];
+	bool hasRequestedCosts = false;
+	bool isProducingResources = false;
 
 	oldplayer = Player;
 
@@ -1258,6 +1268,29 @@ void CUnit::ChangeOwner(CPlayer *newplayer)
 		uins->ChangeOwner(newplayer);
 	}
 
+	// Stop the unit from consuming resources, and remember how
+	// much it did.
+	if (oldplayer->UnitsConsumingResourcesRequested.count(this) != 0) {
+		memcpy(requestedCosts,
+		       oldplayer->UnitsConsumingResourcesRequested[this],
+		       MaxCosts * sizeof(int));
+		hasRequestedCosts = true;
+		oldplayer->RemoveFromUnitsConsumingResources(this);
+	}
+
+	// Likewise, disconnect any resource production from the old
+	// owner.  Data.Harvest.CurrentProduction is unfortunately
+	// uninitialized until SubAction SUB_START_GATHERING, and
+	// then zero until SUB_GATHER_RESOURCE.
+	UnitRemoveProductionAndStorage(this);
+	if (Orders[0]->Action == UnitActionResource
+	    && SubAction == /* SUB_GATHER_RESOURCE */ 60) {
+		isProducingResources = true;
+		for (i = 0; i < MaxCosts; ++i) {
+			oldplayer->ProductionRate[i] -= Data.Harvest.CurrentProduction[i];
+		}
+	}
+
 	//
 	//  Must change food/gold and other.
 	//
@@ -1284,6 +1317,20 @@ void CUnit::ChangeOwner(CPlayer *newplayer)
 	UpdateUnitSightRange(this);
 	MapMarkUnitSight(this);
 
+	// If the unit was trying to consume resources from the old
+	// player, then request similar resources from the new player.
+	// The resources actually granted will be computed by
+	// CalculateCosts called by PlayersEachCycle.
+	if (hasRequestedCosts) {
+		newplayer->AddToUnitsConsumingResources(this, requestedCosts);
+	}
+
+	if (isProducingResources) {
+		for (i = 0; i < MaxCosts; ++i) {
+			newplayer->ProductionRate[i] += Data.Harvest.CurrentProduction[i];
+		}
+	}
+
 	//
 	//  Must change food/gold and other.
 	//
@@ -1807,46 +1854,41 @@ CUnit *UnitFindResource(const CUnit *unit, int x, int y, int range, int resource
 **  Find the next idle worker
 **
 **  @param player    Player's units to search through
-**  @param last      Previous idle worker selected
 **
 **  @return NoUnitP or next idle worker
 */
-CUnit *FindIdleWorker(const CPlayer *player, const CUnit *last)
+CUnit *FindIdleWorker(const CPlayer *player)
 {
 	CUnit *unit;
-	CUnit *FirstUnitFound;
+	CUnit *firstUnitFound;
 	int nunits;
-	int i;
-	int SelectNextUnit;
+	bool selectNextUnit = false;
 
-	FirstUnitFound = NoUnitP;
-	if (last == NoUnitP) {
-		SelectNextUnit = 1;
-	} else {
-		SelectNextUnit = 0;
-	}
+	firstUnitFound = NoUnitP;
 
 	nunits = player->TotalNumUnits;
 
-	for (i = 0; i < nunits; ++i) {
+	for (int i = 0; i < nunits; ++i) {
 		unit = player->Units[i];
 		if (unit->Type->Harvester && !unit->Removed) {
 			if (unit->Orders[0]->Action == UnitActionStill) {
-				if (SelectNextUnit && !IsOnlySelected(unit)) {
+				if (selectNextUnit) {
 					return unit;
 				}
-				if (FirstUnitFound == NULL) {
-					FirstUnitFound = unit;
+				if (firstUnitFound == NoUnitP) {
+					// Use the first possible unit if we can't select next
+					firstUnitFound = unit;
+				}
+				if (!selectNextUnit && IsOnlySelected(unit)) {
+					// If this unit is selected, select next unit
+					selectNextUnit = true;
 				}
 			}
 		}
-		if (unit == last) {
-			SelectNextUnit = 1;
-		}
 	}
 
-	if (FirstUnitFound != NoUnitP && !IsOnlySelected(FirstUnitFound)) {
-		return FirstUnitFound;
+	if (firstUnitFound != NoUnitP && !IsOnlySelected(firstUnitFound)) {
+		return firstUnitFound;
 	}
 
 	return NoUnitP;
@@ -1909,8 +1951,7 @@ CUnit *UnitOnScreen(int x, int y)
 */
 void UnitRemoveConsumingResources(CUnit *unit)
 {
-	if ((unit->Orders[0]->Action == UnitActionBuild && !unit->Type->BuilderOutside && unit->SubAction == 40) ||
-			(unit->Orders[0]->Action == UnitActionRepair && unit->SubAction == 20)) {
+	if (unit->Orders[0]->Action == UnitActionRepair && unit->SubAction == 20) {
 		unit->Player->RemoveFromUnitsConsumingResources(unit);
 	} else if (unit->Orders[0]->Action == UnitActionResource && unit->SubAction >= 55) {
 		for (int u = 0; u < MaxCosts; ++u) {
@@ -1966,25 +2007,7 @@ void LetUnitDie(CUnit *unit)
 	}
 
 	UnitRemoveConsumingResources(unit);
-	if (unit->Orders[0]->Action != UnitActionBuilt) {
-		for (int u = 0; u < MaxCosts; ++u) {
-			unit->Player->ProductionRate[u] -= unit->Type->ProductionRate[u] * unit->ProductionEfficiency / 100;
-			unit->Player->StorageCapacity[u] -= unit->Type->StorageCapacity[u];
-			if (unit->Player->StoredResources[u] > unit->Player->StorageCapacity[u]) {
-				unit->Player->StoredResources[u] = unit->Player->StorageCapacity[u];
-			}
-		}
-	}
-
-	// During resource build, the worker holds the resource amount,
-	// but if canceling building the platform, the worker is already
-	// outside.
-	if (type->CanHarvestFrom &&
-			unit->Orders[0]->Action == UnitActionBuilt &&
-			unit->Data.Built.Worker) {
-		// Restore value for oil-patch
-		memcpy(unit->ResourcesHeld, unit->Data.Built.Worker->ResourcesHeld, sizeof(unit->ResourcesHeld));
-	}
+	UnitRemoveProductionAndStorage(unit);
 
 	// Transporters lose their units and building their workers
 	if (unit->UnitInside) {
@@ -2021,6 +2044,33 @@ void LetUnitDie(CUnit *unit)
 	MapMarkUnitSight(unit);
 }
 
+/**
+** Subtract the production rate and storage capacity of the unit from
+** the player that owns it.  However, do nothing if the unit hasn't
+** yet been fully built, because that means the production rate and
+** storage capacity haven't even been added to the player yet.
+**
+** This function is called when the player is losing the unit: either
+** because the unit is dying, or because the unit is being transferred
+** to another player.
+**
+** This function ignores harvesting.  If the unit may be harvesting
+** some resources, the caller must deduct that from the player in some
+** other way.
+*/
+static void UnitRemoveProductionAndStorage(CUnit *unit)
+{
+	if (unit->Orders[0]->Action != UnitActionBuilt) {
+		for (int u = 0; u < MaxCosts; ++u) {
+			unit->Player->ProductionRate[u] -= unit->Type->ProductionRate[u] * unit->ProductionEfficiency / 100;
+			unit->Player->StorageCapacity[u] -= unit->Type->StorageCapacity[u];
+			if (unit->Player->StoredResources[u] > unit->Player->StorageCapacity[u]) {
+				unit->Player->StoredResources[u] = unit->Player->StorageCapacity[u];
+			}
+		}
+	}
+}
+
 /**
 **  Destroy all units inside unit.
 **
