@@ -62,6 +62,22 @@ static std::list<CGraphic *> Graphics;
 --  Functions
 ----------------------------------------------------------------------------*/
 
+/**
+**  Video draw the graphic clipped.
+**
+**  @param x   X screen position
+**  @param y   Y screen position
+*/
+void CGraphic::DrawClip(int x, int y) const
+{
+	int oldx = x;
+	int oldy = y;
+	int w = Width;
+	int h = Height;
+	CLIP_RECTANGLE(x, y, w, h);
+	DrawSub(x - oldx, y - oldy, w, h, x, y);
+}
+
 /**
 **  Video draw part of graphic.
 **
@@ -560,6 +576,20 @@ CGraphic *CGraphic::ForceNew(const std::string &file, int w, int h)
 	return g;
 }
 
+/**
+**  Clone a graphic
+*/
+CGraphic *CGraphic::Clone() const
+{
+	CGraphic *g = CGraphic::ForceNew(this->File, this->Width, this->Height);
+
+	if (this->IsLoaded()) {
+		g->Load();
+	}
+
+	return g;
+}
+
 /**
 **  Make a new player color graphic object.  Don't reuse a graphic from the
 **  hash table.
@@ -619,7 +649,7 @@ void CGraphic::Load()
 		fprintf(stderr, "Invalid graphic (width, height) %s\n", File.c_str());
 		fprintf(stderr, "Expected: (%d,%d)  Found: (%d,%d)\n",
 			Width, Height, GraphicWidth, GraphicHeight);
-		ExitFatal(1);
+		ExitFatal(-1);
 	}
 
 	NumFrames = GraphicWidth / Width * GraphicHeight / Height;
@@ -1257,7 +1287,6 @@ void CGraphic::MakeShadow()
 	}
 }
 
-#ifdef DEBUG
 void FreeGraphics()
 {
 	std::map<std::string, CGraphic *>::iterator i;
@@ -1266,6 +1295,5 @@ void FreeGraphics()
 		CGraphic::Free((*i).second);
 	}
 }
-#endif
 
 //@}
